#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_QUARTER_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_QUARTER_HPP_INCLUDED

#include <boost/simd/constant/include/constants/quarter.hpp>

#endif
